| Title: | Multiple Ploidy Estimation Tool for all Species Compatible with Flow Cytometry |
|---|---|
| Description: | A graphical user interface tool to estimate ploidy from DNA cells stained with fluorescent dyes and analyzed by flow cytometry, following the methodology of Gómez-Muñoz and Fischer (2024) <doi:10.1101/2024.01.24.577056>. Features include multiple file uploading and configuration, peak fluorescence intensity detection, histogram visualizations, peak error curation, ploidy and genome size calculations, and easy results export. |
| Authors: | Cintia Gómez-Muñoz [aut, cre]
|
| Maintainer: | Cintia Gómez-Muñoz <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.1 |
| Built: | 2026-05-16 06:50:06 UTC |
| Source: | https://github.com/cran/MuPETFlow |
This function launches the Shiny app included in MuPETFlow. Once the application is launched, you can either:
Load your experimental data.
Run an in-app example by clicking the 'Example' button.
runMuPETFlow()runMuPETFlow()
After launching the app, you can follow the app flow, which is divided into three tabs: Peaks, Regression and Summary. Below is a general description of the options available in each tab:
Select a sample (optional): Allows visual exploration of individual samples if desired.
Adjust smoothing (optional): Adjusts the histogram curve for noisy samples.
Adjust window width (optional): Defines the interval where the app will look for peaks.
Select minimum cell count to call a peak (optional): Useful for samples with a low number of events.
Select maximum number of peaks to plot (optional): Useful for samples with heterogeneous populations where more peaks are present.
Select type of analysis: Choose between "Ploidy" or "Genome size" analysis.
Select number of standards: A minimum of two different standards is required, but more are recommended.
Select standard samples and values: This is the ploidy or genome size of your standards.
Results preview: Creates a compiled figure with histograms for all samples.
Save plot: Saves the histograms in either PNG or TIFF format with customizable size and quality. Optionally, you can control the grid layout.
Save table: Exports the parameters used and the estimated ploidy or genome size as a CSV file.
No return value, called for side effects.
if (interactive()) { # Example: Check that the function exists and runs runMuPETFlow() } else { message("This is a Shiny app wrapper. Run interactively to use.") }if (interactive()) { # Example: Check that the function exists and runs runMuPETFlow() } else { message("This is a Shiny app wrapper. Run interactively to use.") }